#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SCALAR_ILOG2_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SCALAR_ILOG2_HPP_INCLUDED

#include <boost/simd/bitwise/include/functions/scalar/ilog2.hpp>

#endif
